@@ -10,7 +10,8 @@ sub parse {
         $stack->add(Message::Stack::Message->new(
             id      => "missing_$f",
             scope   => $scope,
-            subject => $f
+            subject => $f,
+            level   => 'error'
         ));
     }
 
@@ -18,9 +19,10 @@ sub parse {
         $stack->add(Message::Stack::Message->new(
             id      => "invalid_$f",
             scope   => $scope,
-            subject => $f
+            subject => $f,
+            level   => 'error'
         ));
     }
 }
 
-1;
\ No newline at end of file
+1;
